@@ -2,11 +2,13 @@ import time
 
 from aminer import AMinerConfig
 from aminer.AMinerUtils import AnalysisContext
-from aminer.parsing import ParsedAtomHandlerInterface
+from aminer.events import EventSourceInterface
+from aminer.input import AtomHandlerInterface
 from aminer.util import TimeTriggeredComponentInterface
 from aminer.util import PersistencyUtil
 
-class MissingMatchPathValueDetector(ParsedAtomHandlerInterface, TimeTriggeredComponentInterface):
+class MissingMatchPathValueDetector(AtomHandlerInterface,
+    TimeTriggeredComponentInterface, EventSourceInterface):
   """This class creates events when an expected value is not seen
   within a given timespan, e.g. because the service was deactivated
   or logging disabled unexpectedly. This is complementary to the
@@ -38,11 +40,12 @@ class MissingMatchPathValueDetector(ParsedAtomHandlerInterface, TimeTriggeredCom
       self.expectedValuesDict=persistenceData
 
 
-  def receiveParsedAtom(self, atomData, match):
-    matchElement=match.getMatchDictionary().get(self.targetPath, None)
-    if matchElement==None: return
+  def receiveAtom(self, logAtom):
+    matchElement=logAtom.parserMatch.getMatchDictionary().get(
+        self.targetPath, None)
+    if matchElement==None: return(False)
     value=matchElement.matchObject
-    timeStamp=match.getDefaultTimestamp()
+    timeStamp=logAtom.getTimestamp()
     detectorInfo=self.expectedValuesDict.get(value, None)
     if detectorInfo!=None:
 # Just update the last seen value and switch from non-reporting
@@ -88,7 +91,8 @@ class MissingMatchPathValueDetector(ParsedAtomHandlerInterface, TimeTriggeredCom
         for listener in self.anomalyEventHandlers:
           listener.receiveEvent('Analysis.%s' % self.__class__.__name__,
               'Interval too large between values for path %s:%s ' % (self.targetPath, messagePart),
-              [atomData], missingValueList, self)
+              [logAtom.rawData], missingValueList, self)
+    return(True)
 
 
   def setCheckValue(self, value, interval):
@@ -130,3 +134,24 @@ class MissingMatchPathValueDetector(ParsedAtomHandlerInterface, TimeTriggeredCom
     """Immediately write persistence data to storage."""
     PersistencyUtil.storeJson(self.persistenceFileName, self.expectedValuesDict)
     self.nextPersistTime=None
+
+
+  def whitelistEvent(self, eventType, sortedLogLines, eventData,
+      whitelistingData):
+    """Whitelist an event generated by this source using the information
+    emitted when generating the event.
+    @return a message with information about whitelisting
+    @throws Exception when whitelisting of this special event
+    using given whitelistingData was not possible."""
+    if eventType!='Analysis.%s' % self.__class__.__name__:
+      raise Exception('Event not from this source')
+    if not(isinstance(whitelistData, int)):
+      raise Exception('Whitelisting data has to integer with new interval, -1 to reset to defaults, other negative value to remove the entry')
+    newInterval=whitelistingData
+    if newInterval==-1: newInterval=self.defaultInterval
+    for keyName, delta, detectorInfo in eventData:
+      if newInterval<0:
+        self.removeCheckValue(keyName)
+      else:
+        self.setCheckValue(keyName, newInterval)
+    return('Updated %d entries' % len(eventData))
