@@ -2,11 +2,13 @@ import time
 
 from aminer import AMinerConfig
 from aminer.AMinerUtils import AnalysisContext
-from aminer.parsing import ParsedAtomHandlerInterface
+from aminer.events import EventSourceInterface
+from aminer.input import AtomHandlerInterface
 from aminer.util import TimeTriggeredComponentInterface
 from aminer.util import PersistencyUtil
 
-class NewMatchPathDetector(ParsedAtomHandlerInterface, TimeTriggeredComponentInterface):
+class NewMatchPathDetector(AtomHandlerInterface,
+    TimeTriggeredComponentInterface, EventSourceInterface):
   """This class creates events when new data path was found in
   a parsed atom."""
 
@@ -27,9 +29,16 @@ class NewMatchPathDetector(ParsedAtomHandlerInterface, TimeTriggeredComponentInt
       self.knownPathSet=set(persistenceData)
 
 
-  def receiveParsedAtom(self, atomData, match):
+  def receiveAtom(self, logAtom):
+    """Receive on parsed atom and the information about the parser
+    match.
+    @param logAtom the parsed log atom
+    @return True if this handler was really able to handle and
+    process the match. Depending on this information, the caller
+    may decide if it makes sense passing the parsed atom also
+    to other handlers."""
     unknownPathList=[]
-    for path in match.getMatchDictionary().keys():
+    for path in logAtom.parserMatch.getMatchDictionary().keys():
       if not(path in self.knownPathSet):
         unknownPathList.append(path)
         if self.autoIncludeFlag:
@@ -40,7 +49,8 @@ class NewMatchPathDetector(ParsedAtomHandlerInterface, TimeTriggeredComponentInt
       for listener in self.anomalyEventHandlers:
         listener.receiveEvent('Analysis.%s' % self.__class__.__name__,
             'New path(es) %s ' % (', '.join(unknownPathList)),
-            [atomData], [match, unknownPathList], self)
+            [logAtom.rawData], [logAtom, unknownPathList], self)
+    return(True)
 
 
   def getTimeTriggerClass(self):
@@ -64,3 +74,22 @@ class NewMatchPathDetector(ParsedAtomHandlerInterface, TimeTriggeredComponentInt
     """Immediately write persistence data to storage."""
     PersistencyUtil.storeJson(self.persistenceFileName, list(self.knownPathSet))
     self.nextPersistTime=None
+
+  def whitelistEvent(self, eventType, sortedLogLines, eventData,
+      whitelistingData):
+    """Whitelist an event generated by this source using the information
+    emitted when generating the event.
+    @return a message with information about whitelisting
+    @throws Exception when whitelisting of this special event
+    using given whitelistingData was not possible."""
+    if eventType!='Analysis.%s' % self.__class__.__name__:
+      raise Exception('Event not from this source')
+    if whitelistingData!=None:
+      raise Exception('Whitelisting data not understood by this detector')
+    whitelistedStr=''
+    for pathName in eventData[1]:
+      if pathName in self.knownPathSet: continue
+      self.knownPathSet.add(pathName)
+      if len(whitelistedStr)!=0: whitelistedStr+=', '
+      whitelistedStr+=repr(pathName)
+    return('Whitelisted path(es) %s in %s' % (whitelistedStr, sortedLogLines[0]))
